#!/usr/bin/perl
use strict;
use Data::Dumper;
use VR::API;

# environment variables needed by VR::API - fill in your values
$ENV{VR_API_SOAP_ENDPOINT} = 'https://api.verticalresponse.com/1.0/VRAPI';
$ENV{HTTPS_PKCS12_FILE} = "FIXME: path to your .p12 file";
$ENV{HTTPS_PKCS12_PASSWORD} = "FIXME: your .p12 fiel passphrase"; # Not needed for passphraseless PKCS#12 keystores

# test subjects - fill in your values
my $email1 = 'FIXME: your test email address';
my $email2 = 'FIXME: another test email address';

# login information - fill in your values
my $username = 'FIXME: your application login username (an email address)';
my $password = 'FIXME: your application login password';

print "logging in...\n";
my $vrapi = new VR::API;
my $sid = $vrapi->login( {
                          username => $username,
                          password => $password,
                          session_duration_minutes => 4
                         }
                       );

print "session ID is $sid \n";
print "creating list...\n";
 #create list
 my $lid = $vrapi->createList( {
                                session_id => $sid,
                                name =>  'list_' . time(),
                                type => 'email'
                               }
                             );


print "List ID: " . $lid . "\n" ;
print "Adding member to the list...\n";
 # # insert email address into the list
    my $list_res = $vrapi->addListMember( {
                                           session_id => $sid,
                                           list_member => {
                                                          list_id =>$lid,
                                                          member_data => [
                                                                          {
                                                                           name =>'email_address',
                                                                           value => $email1
                                                                          },
                                                                          {
                                                                           name => 'First_Name',
                                                                           value => 'Allen'
                                                                          },
                                                                          {
                                                                           name => 'Last_Name',
                                                                           value => 'Corona'
                                                                          },
                                                                         ]
                                                           }
                                          } 
                                        );


#  # lets create a campaign
print "creating email campaign...\n";
my $camp_resp = $vrapi->createEmailCampaign( {
                                              session_id => $sid,
                                                 email_campaign =>                                                                  
                                                 {
                                                  name => "campaign_" . time(),
                                                  type => 'freeform',
                                                  from_label => 'XYY_newsletter',
                                                  support_email => 'allen@verticalresponse',
                                                  send_friend => 'true',
                                                  redirect_url => 'http://www.verticalresponse.com/labs',
                                                  contents => [
                                                               {
                                                                type => 'freeform_html',
                                                                copy => '<h1>Hello World</h1"><br>Pretty original, huh?',
                                                               },
                                                               {
                                                                type => 'freeform_text',
                                                                copy => 'Hola World!',
                                                               },
                                                               {
                                                                type => 'subject',
                                                                copy => 'My original subject line',
                                                               },
                                                               {
                                                                type => 'unsub_message',
                                                                copy => 'You requested these emails, now you want to leave? If so',
                                                               },
                                                              ]
                                                 }                                                 
                                                }
                                              );
print "email campaign ID: " . $camp_resp . "\n";
print "testing email campaign ...\n";



my $rec1 = [{ 
             name => 'email_address',
             value=> $email1,
            },
            {
            name => 'first_name',
            value=> 'Allen',
            }
           ];

my $rec2 = [{
             name => 'email_address',
             value=> $email2,
          },
           {
            name => 'first_name',
            value=> 'allen2',
           }
           ];

print "Sending tests to: \n";
print  "\t" . $email1 . "\n\t" . $email2 . "\n";

my $test_resp = $vrapi->sendEmailCampaignTest(
                                              {
                                               session_id => $sid,
                                               campaign_id => $camp_resp,
                                               recipients => [ $rec1, $rec2 ],                                               
                                              }
);



# need to attach the list first and then schedule the message to be sent out
print "attaching list to email campaign...\n";
my $attach_resp = $vrapi->setCampaignLists( {
                                             session_id => $sid,
                                             campaign_id => $camp_resp,
                                             list_ids => [$lid],
                                            }
                                          );

# send out the campaign
print "launching email campaign...";
my $launch_resp = $vrapi->launchEmailCampaign( {
                                               session_id => $sid,
                                               campaign_id => $camp_resp,
                                              }
                                            );
print "now\n";
print "Lifecycle complete. Please look at the other script to view the campaign data.\n";
